#[repr(u8)]pub enum CompressionAlgorithm {
Zstd = 0,
Lz4 = 1,
}Expand description
The compression algorithm used to compress the chunks.
Variants
Implementations
Sourceimpl CompressionAlgorithm
impl CompressionAlgorithm
Sourcepub fn decompressor(&self) -> Decompressor
pub fn decompressor(&self) -> Decompressor
Returns a decompressor that can decompress a chunk compressed with this compression algorithm.
Sourcepub fn thread_local_decompressor(&self) -> ThreadLocalDecompressor
pub fn thread_local_decompressor(&self) -> ThreadLocalDecompressor
Returns a decompressor that can decompress a chunk compressed with this compression algorithm. Some decompressors require a large state object that is expensive to create but can be reused for many decompressions. A thread-local decompressor stores the state object in a thread-local variable.