make_blob_image

Function make_blob_image 

pub async fn make_blob_image(
    output_image_path: &str,
    sparse_output_image_path: Option<&str>,
    blobs: Vec<(Hash, PathBuf)>,
    json_output_path: &str,
    target_size: Option<u64>,
    compression_algorithm: Option<CompressionAlgorithm>,
) -> Result<(), Error>
Generates an Fxfs image containing a blob volume with the blobs specified in manifest_path. Creates the block image at output_image_path and writes a blobs.json file to json_output_path. If target_size bytes is set, the raw image will be set to exactly this size (and an error is returned if the contents exceed that size). If unset (or 0), the image will be truncated to twice the size of its contents, which is a heuristic that gives us roughly enough space for normal usage of the image. If sparse_output_image_path is set, an image will also be emitted in the Android sparse format, which is suitable for flashing via fastboot. The sparse image’s logical size and contents are identical to the raw image, but its actual size will likely be smaller.