pub struct BlobToInstall { /* private fields */ }Expand description
Represents a blob ready to be installed into an FxBlob instance.
Implementations
Sourceimpl BlobToInstall
impl BlobToInstall
Sourcepub fn new(
data: Vec<u8>,
fs_block_size: usize,
compression_algorithm: Option<CompressionAlgorithm>,
) -> Result<Self, Error>
pub fn new( data: Vec<u8>, fs_block_size: usize, compression_algorithm: Option<CompressionAlgorithm>, ) -> Result<Self, Error>
Create a new blob ready for installation with FxBlobBuilder::install_blob.
Sourcepub fn new_from_file(
path: PathBuf,
fs_block_size: usize,
compression_algorithm: Option<CompressionAlgorithm>,
) -> Result<Self, Error>
pub fn new_from_file( path: PathBuf, fs_block_size: usize, compression_algorithm: Option<CompressionAlgorithm>, ) -> Result<Self, Error>
Create a new blob ready for installation with FxBlobBuilder::install_blob from an
existing file on disk.
pub fn hash(&self) -> Hash