pub struct FxBlobBuilder { /* private fields */ }Expand description
Builder used to construct a new Fxblob instance ready for flashing to a device.
Implementations
Sourceimpl FxBlobBuilder
impl FxBlobBuilder
Sourcepub async fn new(device: DeviceHolder) -> Result<Self, Error>
pub async fn new(device: DeviceHolder) -> Result<Self, Error>
Creates a new FxBlobBuilder backed by the given device.
Sourcepub async fn finalize(self) -> Result<(DeviceHolder, u64), Error>
pub async fn finalize(self) -> Result<(DeviceHolder, u64), Error>
Finalizes building the FxBlob instance this builder represents. The filesystem will not be usable unless this is called. Returns the filesystem’s DeviceHolder and the last offset in bytes which was used on the device.
Sourcepub async fn install_blob(
&self,
blob: &BlobToInstall,
) -> Result<DataObjectHandle<ObjectStore>, Error>
pub async fn install_blob( &self, blob: &BlobToInstall, ) -> Result<DataObjectHandle<ObjectStore>, Error>
Installs the given blob into the filesystem, returning a handle to the new object.
Sourcepub fn generate_blob(
&self,
data: Vec<u8>,
compression_algorithm: Option<CompressionAlgorithm>,
) -> Result<BlobToInstall, Error>
pub fn generate_blob( &self, data: Vec<u8>, compression_algorithm: Option<CompressionAlgorithm>, ) -> Result<BlobToInstall, Error>
Helper function to quickly create a blob to install from in-memory data. Mainly for testing.